<?php
class WPSW_Setup_Wizard {
    private $step   = '';
    private $steps  = array();
    public function __construct() {
        if ( current_user_can( 'manage_options' ) && current_user_can('administrator') ) {
            $this->setup_wizard();
        }
    }
    public function setup_wizard() {
        if ( empty( $_GET['page'] ) || 'wpsw_show_setup_wiz' !== $_GET['page'] ) {
            return;
        }
        
        $this->steps = array(
            'intro' => array(
                'name'    =>  esc_html__( 'Introduction', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_introduction' ),
                'handler' => ''
            ),
            'content' => array(
                'name'    =>  esc_html__( 'Content', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_basic' ),
                'handler' => array( $this, 'setup_step_basic_save' )
            ),
            'legal' => array(
                'name'    =>  esc_html__( 'Legal', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_legal' ),
                'handler' => array( $this, 'setup_step_legal_save' )
            ),
            'gdpr' => array(
                'name'    =>  esc_html__( 'GDPR', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_gdpr' ),
                'handler' => array( $this, 'setup_step_gdpr_save' )
            ),
            'themes' => array(
                'name'    =>  esc_html__( 'Themes', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_theme' ),
                'handler' => array( $this, 'setup_step_theme_save' ),
            ),
            'plugins' => array(
                'name'    =>  esc_html__( 'Plugins', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_plugin' ),
                'handler' => array( $this, 'setup_step_plugin_save' ),
            ),
            'security' => array(
                'name'    =>  esc_html__( 'Security', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_security' ),
                'handler' => array( $this, 'setup_step_security_save' ),
            ),
            'seo' => array(
                'name'    =>  esc_html__( 'SEO', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_seo' ),
                'handler' => array( $this, 'setup_step_seo_save' ),
            ),
            'social' => array(
                'name'    =>  esc_html__( 'Social', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_social' ),
                'handler' => array( $this, 'setup_step_social_save' ),
            ),
            'monetize' => array(
                'name'    =>  esc_html__( 'Monetize', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_monetize' ),
                'handler' => array( $this, 'setup_step_monetize_save' ),
            ),
            'speed' => array(
                'name'    =>  esc_html__( 'Speed', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_speed' ),
                'handler' => array( $this, 'setup_step_speed_save' ),
            ),
            'next_steps' => array(
                'name'    =>  esc_html__( 'Ready!', 'wp-setup-wizard' ),
                'view'    => array( $this, 'setup_step_ready' ),
                'handler' => ''
            )
        );

        $this->step = isset( $_GET['step'] ) ? sanitize_key( $_GET['step'] ) : current( array_keys( $this->steps ) );
        wp_enqueue_style( 'wpsw-setup', plugins_url('styles/setup.css', __FILE__), array( 'dashicons', 'install' ) );

        if ( ! empty( $_POST['save_step'] ) && isset( $this->steps[ $this->step ]['handler'] ) ) {
            call_user_func( $this->steps[ $this->step ]['handler'] );
        }

        ob_start();
        $this->setup_wizard_header();
        $this->setup_wizard_steps();
        $this->setup_wizard_content();
        $this->setup_wizard_footer();
        exit;
    }

    public function get_next_step_link() {
        $keys = array_keys( $this->steps );
        return add_query_arg( 'step', $keys[ array_search( $this->step, array_keys( $this->steps ) ) + 1 ], remove_query_arg( 'translation_updated' ) );
    }
    
    public function get_prev_step_link() {
        $keys = array_keys( $this->steps );
        return add_query_arg( 'step', $keys[ array_search( $this->step, array_keys( $this->steps ) ) - 1 ], remove_query_arg( 'translation_updated' ) );
    }

    public function setup_wizard_header() {
        ?>
        <!DOCTYPE html>
        <html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
        <head>
            <meta name="viewport" content="width=device-width" />
            <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
            <title><?php esc_html_e( 'WP Setup Wizard', 'wp-setup-wizard' ); ?></title>
            <?php do_action( 'admin_print_styles' ); ?>
            <?php do_action( 'admin_head' ); ?>
        </head>
        <body class="wpsw-setup wp-core-ui">
            <h1 class="wpsw-logo"><a target="_blank" href="https://coderevolution.ro/">WP Setup Wizard</a></h1>
        <?php
    }

    public function setup_wizard_footer() {
        ?>
            <?php if ( 'next_steps' === $this->step ) : ?>
                <a class="wpsw-return-to-dashboard" href="<?php echo esc_url_raw( admin_url() . '?wpsw_done_config=1' ); ?>"><?php esc_html_e( 'Return to the WordPress Dashboard', 'wp-setup-wizard' ); ?></a>
            <?php endif; ?>
            </body>
        </html>
        <?php
    }

    public function setup_wizard_steps() {
        $output_steps = $this->steps;
        array_shift( $output_steps );
        ?>
        <ol class="wpsw-setup-steps">
            <?php foreach ( $output_steps as $step_key => $step ) : ?>
                <li class="<?php
                    if ( $step_key === $this->step ) {
                        echo 'active';
                    } elseif ( array_search( $this->step, array_keys( $this->steps ) ) > array_search( $step_key, array_keys( $this->steps ) ) ) {
                        echo 'done';
                    }
                    ?>"><a href="<?php echo esc_url_raw( admin_url( 'index.php?page=wpsw_show_setup_wiz&step=' . $step_key ) ); ?>"><?php echo esc_html( $step['name'] ); ?></a>
                </li>
            <?php endforeach; ?>
        </ol>
        <?php
    }

    public function setup_wizard_content() {
        echo '<div class="wpsw-setup-content">';
        call_user_func( $this->steps[ $this->step ]['view'] );
        echo '</div>';
    }

    public function next_step_buttons($first = false) {
        ?>
        <p class="wpsw-setup-actions step">
            <input type="submit" class="button-primary button button-large button-next" value="<?php esc_attr_e( 'Continue', 'wp-setup-wizard' ); ?>" name="save_step" />
            <a href="<?php echo esc_url_raw( $this->get_next_step_link() ); ?>" class="button button-large button-next"><?php esc_html_e( 'Skip this step', 'wp-setup-wizard' ); ?></a>
            <?php 
            if($first == false)
            {
                echo '<a href="' . esc_url_raw( $this->get_prev_step_link() ) . '" class="button button-large button-next">' . esc_html__( 'Back', 'wp-setup-wizard' ) . '</a>';
            }
            else
            {
                echo '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_welcome_settings&wpsw_done_config=1') ) . '" class="button button-large button-next">' . esc_html__( 'Abort', 'wp-setup-wizard' ) . '</a>';
            }
            wp_nonce_field( 'wpsw_show_setup_wiz' ); ?>
        </p>
        <?php
    }

    public function setup_step_introduction() {
        ?>
        <h1><?php esc_html_e( 'Welcome to the future of configuring WordPress!', 'wp-setup-wizard' ); ?></h1>
        <p><?php echo wp_kses_post( esc_html__('Thank you for choosing WP Setup Wizard. An easier way to set up and manage your WordPress website! This quick setup wizard will help you configure the basic settings for your site. It’s completely optional and shouldn’t take longer than five minutes.', 'wp-setup-wizard' ) ); ?></p>
        <p><?php esc_html_e( 'Need help with configuring the plugin? Check this tutorial video series: ', 'wp-setup-wizard' ); ?><a href="https://www.youtube.com/watch?v=iNjozJ9CqdE&list=PLEiGTaa0iBIjOiZM2FQJJMiroKAraOR2o&index=1" target="_blank"><?php esc_html_e( 'WP Setup Wizard', 'wp-setup-wizard' ); ?></a></p>
        <p><?php esc_html_e( 'No time right now? If you don’t want to go through the wizard, you can skip and return to the plugin\'s dashboard. Come back anytime if you change your mind!', 'wp-setup-wizard' ); ?></p>
        <p class="wpsw-setup-actions step">
            <a href="<?php echo esc_url_raw( $this->get_next_step_link() ); ?>" class="button-primary button button-large button-next"><?php esc_html_e( 'Let\'s Go!', 'wp-setup-wizard' ); ?></a>
            <a href="<?php echo esc_url_raw( admin_url( 'admin.php?page=wpsw_welcome_settings' ) ); ?>" class="button button-large"><?php esc_html_e( 'Not right now', 'wp-setup-wizard' ); ?></a>
        </p>
        <?php
    }

    public function setup_step_basic() {
        
        $site_name = '';
        $tagline = '';
        $admin_email = '';
        $defa_cat = '';
        $set_permalink = '';
        $users_can_register = '';
        $wpsw_date_format = '';
        $wpsw_time_format = '';
        wpsw_get_content_info($site_name, $tagline, $admin_email, $defa_cat, $set_permalink, $users_can_register, $wpsw_date_format, $wpsw_time_format);
        ?>
        <h1><?php esc_html_e( 'Content Settings', 'wp-setup-wizard' ); ?></h1>

        <form method="post">

            <table class="form-table">
                <tr><th><h3><?php esc_html_e( 'Site Settings:', 'wp-setup-wizard' ); ?></h3></th><td><span class="description">
                            <?php esc_html_e( 'Some basic WordPress settings.', 'wp-setup-wizard' ); ?>
                        </span></td></tr>
                <tr>
                    <th scope="row"><label for="site_name"><?php esc_html_e( 'Site Title', 'wp-setup-wizard' ); ?></label></th>
                    <td><input type="text" placeholder="<?php esc_html_e( 'Site Title', 'wp-setup-wizard' ); ?>" name="site_name" value="<?php echo esc_attr($site_name);?>" id="site_name" class="wpsw-date-field">
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="tagline"><?php esc_html_e( 'Tagline', 'wp-setup-wizard' ); ?></label></th>
                    <td><input type="text" placeholder="<?php esc_html_e( 'In a few words, explain what this site is about.', 'wp-setup-wizard' ); ?>" name="tagline" value="<?php echo esc_attr($tagline);?>" id="tagline" class="wpsw-date-field">
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="admin_email"><?php esc_html_e( 'Admin Email', 'wp-setup-wizard' ); ?></label></th>
                    <td><input type="email" placeholder="<?php esc_html_e( 'Administrator email', 'wp-setup-wizard' ); ?>" name="admin_email" value="<?php echo esc_attr($admin_email);?>" id="admin_email" class="wpsw-date-field">
                    </td>
                </tr>
                <tr><th><h3><?php esc_html_e( 'Delete All:', 'wp-setup-wizard' ); ?></h3></th><td><span class="description">
                            <?php esc_html_e( 'Warning, irreversible actions!', 'wp-setup-wizard' ); ?>
                        </span></td></tr>
                <tr>
                    <th scope="row"><label for="delete_posts"><?php esc_html_e( 'Posts', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="delete_posts" id="delete_posts" class="switch-input">
                        <label for="delete_posts" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to delete all posts from this website?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="delete_pages"><?php esc_html_e( 'Pages', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="delete_pages" id="delete_pages" class="switch-input">
                        <label for="delete_pages" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to delete all pages from this website?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="delete_categories"><?php esc_html_e( 'Categories', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="delete_categories" id="delete_categories" class="switch-input">
                        <label for="delete_categories" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to delete all categories from this website?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="delete_tags"><?php esc_html_e( 'Tags', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="delete_tags" id="delete_tags" class="switch-input">
                        <label for="delete_tags" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to delete all tags from this website?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="delete_att"><?php esc_html_e( 'Attachments', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="delete_att" id="delete_att" class="switch-input">
                        <label for="delete_att" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to delete all attachments from this website?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="delete_comm"><?php esc_html_e( 'Comments', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="delete_comm" id="delete_comm" class="switch-input">
                        <label for="delete_comm" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to delete all comments from this website?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr><th><h3><?php esc_html_e( 'Create Content:', 'wp-setup-wizard' ); ?></h3></th><td><span class="description">
                            <?php esc_html_e( 'Create new content for your website.', 'wp-setup-wizard' ); ?>
                        </span></td></tr>
                <tr>
                    <th scope="row"><label for="make_about"><?php esc_html_e( '"About Us" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_about" id="make_about" class="switch-input">
                        <label for="make_about" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create an "About Us" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_contact"><?php esc_html_e( '"Contact Us" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_contact" id="make_contact" class="switch-input">
                        <label for="make_contact" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create a "Contact Us" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_affiliate"><?php esc_html_e( '"Affiliate Disclosure" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_affiliate" id="make_affiliate" class="switch-input">
                        <label for="make_affiliate" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create an "Affiliate Disclosure" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_amazon"><?php esc_html_e( '"Amazon Affiliate Disclosure" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_amazon" id="make_amazon" class="switch-input">
                        <label for="make_amazon" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create an "Amazon Affiliate Disclosure" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_antispam"><?php esc_html_e( '"AnstiSpam Policy" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_antispam" id="make_antispam" class="switch-input">
                        <label for="make_antispam" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create an "AnstiSpam Policy" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_cookie"><?php esc_html_e( '"Cookie Policy" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_cookie" id="make_cookie" class="switch-input">
                        <label for="make_cookie" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create a "Cookie Policy" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_gdpr"><?php esc_html_e( '"GDPR Requests" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_gdpr" id="make_gdpr" class="switch-input">
                        <label for="make_gdpr" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create a "GDPR Requests" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_copyright"><?php esc_html_e( '"Copyright Policy" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_copyright" id="make_copyright" class="switch-input">
                        <label for="make_copyright" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create a "Copyright Policy" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_earnings"><?php esc_html_e( '"Earnings Disclaimer" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_earnings" id="make_earnings" class="switch-input">
                        <label for="make_earnings" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create an "Earnings Disclaimer" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_medical"><?php esc_html_e( '"Medical Disclaimer" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_medical" id="make_medical" class="switch-input">
                        <label for="make_medical" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create a "Medical Disclaimer" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_privacy"><?php esc_html_e( '"Privacy Policy" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_privacy" id="make_privacy" class="switch-input">
                        <label for="make_privacy" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create a "Privacy Policy" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="make_terms"><?php esc_html_e( '"Terms of Service" Page', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="make_terms" id="make_terms" class="switch-input">
                        <label for="make_terms" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create a "Terms of Service" page?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="create_posts"><?php esc_html_e( 'Create Blank Posts', 'wp-setup-wizard' ); ?></label></th>
                    <td><textarea placeholder="<?php esc_html_e( 'Enter a list of comma separated posts titles to create.', 'wp-setup-wizard' ); ?>" name="create_posts" id="create_posts" class="wpsw-date-field"></textarea>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="create_pages"><?php esc_html_e( 'Create Blank Pages', 'wp-setup-wizard' ); ?></label></th>
                    <td><textarea placeholder="<?php esc_html_e( 'Enter a list of comma separated page titles to create.', 'wp-setup-wizard' ); ?>" name="create_pages" id="create_pages" class="wpsw-date-field"></textarea>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="create_categories"><?php esc_html_e( 'Create Categories', 'wp-setup-wizard' ); ?></label></th>
                    <td><textarea placeholder="<?php esc_html_e( 'Enter a list of comma separated categories to create.', 'wp-setup-wizard' ); ?>" name="create_categories" id="create_categories" class="wpsw-date-field"></textarea>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="create_tags"><?php esc_html_e( 'Create Tags', 'wp-setup-wizard' ); ?></label></th>
                    <td><textarea placeholder="<?php esc_html_e( 'Enter a list of comma separated tags to create.', 'wp-setup-wizard' ); ?>" name="create_tags" id="create_tags" class="wpsw-date-field"></textarea>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="create_dummy"><?php esc_html_e( 'Create Dummy Content', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="create_dummy" id="create_dummy" class="switch-input">
                        <label for="create_dummy" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to create dummy posts and pages for this site?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr><th><h3><?php esc_html_e( 'Comment Settings:', 'wp-setup-wizard' ); ?></h3></th><td><span class="description">
                            <?php esc_html_e( 'Commenting related settings.', 'wp-setup-wizard' ); ?>
                        </span></td></tr>   
                <tr>
                    <th scope="row"><label for="comm_email"><?php esc_html_e( 'New Comment Email Notification', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="comm_email" id="comm_email" class="switch-input"<?php $comm_not = get_option('comments_notify');if($comm_not == '1') {echo ' checked';}?> >
                        <label for="comm_email" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'E-mail me when anyone posts a comment.', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="comm_mod"><?php esc_html_e( 'Comment Moderation Email Notification', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="comm_mod" id="comm_mod" class="switch-input"<?php $comm_not = get_option('moderation_notify');if($comm_not == '1') {echo ' checked';}?> >
                        <label for="comm_mod" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'E-mail me when comment is held for moderation.', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="comm_enforce"><?php esc_html_e( 'Enforce Comment Moderation', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="comm_enforce" id="comm_enforce" class="switch-input"<?php $comm_not = get_option('comment_moderation');if($comm_not == '1') {echo ' checked';}?> >
                        <label for="comm_enforce" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Comments must be moderated before being published.', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="dcom_post"><?php esc_html_e( 'Disable Comments on Posts', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="dcom_post" id="dcom_post" class="switch-input"<?php $dcom_post = get_option('wpsw_d_pocomm');if($dcom_post == '1') {echo ' checked';}?> >
                        <label for="dcom_post" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to disable comments on posts?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="dcom_page"><?php esc_html_e( 'Disable Comments on Pages', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="dcom_page" id="dcom_page" class="switch-input"<?php $dcom_page = get_option('wpsw_d_pacomm');if($dcom_page == '1') {echo ' checked';}?> >
                        <label for="dcom_page" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to disable comments on pages?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="comm_fb"><?php esc_html_e( 'Enable Facebook Comments', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="comm_fb" id="comm_fb" class="switch-input"<?php $comm_fb = get_option('wpsw_comm_fb');if($comm_fb == '1') {echo ' checked';}?> >
                        <label for="comm_fb" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Replace WordPress comments with Facebook comments.', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
            </table>

            <?php $this->next_step_buttons(true); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_admin_settings#vcc-SiteSettings') ) . '" target="_blank">';esc_html_e( 'Content Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }
public function setup_step_gdpr() {
    $noeu = get_option( 'wpsw_noeutraffic');
    $noeuredirect = get_option( 'wpsw_noeuredirect'); 
    $noeutext = get_option( 'wpsw_noeutext'); 
        ?>
        <h1><?php esc_html_e( 'GDPR Settings', 'wp-setup-wizard' ); ?></h1>
        <form method="post">

            <table class="form-table">
                <tr>
                <th scope="row"><label for="show_time"><?php esc_html_e( 'Do Not Accept Traffic From EU Visitors', 'wp-setup-wizard' ); ?></label></th><td>
                    <input type="checkbox" id="noeutraffic" name="noeutraffic" class="switch-input"<?php if($noeu == '1'){echo ' checked';}?> >
                    <label for="noeutraffic" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Check if you do not want to accept traffic from EU visitors. In this case, your website will not need to be GDPR compliant.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr>
        <th scope="row"><label for="show_time"><?php esc_html_e( 'EU Visitors Redirect URL', 'wp-setup-wizard' ); ?></label></th><td>
                    <div>
                    <input type="url" validator="url" pattern="https?://.*" id="noeuredirect" placeholder="<?php esc_html_e( 'Redirect URL for EU Visitors', 'wp-setup-wizard' ); ?>" name="noeuredirect" value="<?php echo esc_attr($noeuredirect);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the redirect URL for EU visitors. This works only if the above checkbox is checked.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr>
        <th scope="row"><label for="show_time"><?php esc_html_e( 'EU Visitors Not Allowed Text', 'wp-setup-wizard' ); ?></label></th><td>
                    <div>
                    <textarea id="noeutext" placeholder="<?php esc_html_e( 'Sorry, but we are not accepting traffic from the EU region.', 'wp-setup-wizard' ); ?>" name="noeutext"><?php echo esc_attr($noeutext);?></textarea>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the text that will appear to EU visitors who are not allowed on your website. This works only if the above checkbox is checked and the \'EU Visitors Redirect URL\' is left blank. The default text is (if you leave this field blank): \'Sorry, but we are not accepting traffic from the EU region.\'', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
            </table>

            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_legal#vcc-GDPR') ) . '" target="_blank">';esc_html_e( 'GDPR Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
}

public function setup_step_security() {
    $wpsw_enable_limitlogin = get_option('wpsw_enable_limitlogin');
	$wpsw_custom_login = get_option('wpsw_custom_login');
	$wpsw_ssl_front = get_option('wpsw_ssl_front');
	$wpsw_ssl_admin = get_option('wpsw_ssl_admin');
    $recaptchakey = get_option( 'wpsw_recaptchakey'); 
    $recaptchasecret = get_option( 'wpsw_recaptchasecret');
    $wpsw_captcha_shortcode = get_option( 'wpsw_captcha_shortcode');
    $wpsw_captcha_contact = get_option( 'wpsw_captcha_contact');
    $wpsw_captcha_login = get_option( 'wpsw_captcha_login');
    $wpsw_captcha_comment = get_option( 'wpsw_captcha_comment'); 
        ?>
        <h1><?php esc_html_e( 'Security Settings', 'wp-setup-wizard' ); ?></h1>
        <form method="post">
        <div class="cr_autocomplete">
            <input type="password" id="PreventChromeAutocomplete" 
               name="PreventChromeAutocomplete" autocomplete="address-level4" />
         </div>
            <table class="form-table">
        <tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Limit Login Attempts Count', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <input type="number" autocomplete="off" id="wpsw_enable_limitlogin" placeholder="<?php esc_html_e( 'Enable limit login attempts count', 'wp-setup-wizard' ); ?>" name="wpsw_enable_limitlogin" value="<?php echo esc_attr($wpsw_enable_limitlogin);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to limit login attempts? To disable this feature, leave this field blank.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Change WordPress Login URL', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <span class="wpsw50p"><?php echo site_url('/');?></span><input class="wpsw50p" type="text" autocomplete="off" id="wpsw_custom_login" placeholder="<?php esc_html_e( 'Custom login slug', 'wp-setup-wizard' ); ?>" name="wpsw_custom_login" value="<?php echo esc_attr($wpsw_custom_login);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to change the WordPress default login URL from wp-login.php to a custom one? To disable this feature, leave this field blank.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Enforce HTTPS on Front End', 'wp-setup-wizard' ); ?></label></th>
        <td>
					<input type="checkbox" id="wpsw_ssl_front" name="wpsw_ssl_front" class="switch-input" <?php if($wpsw_ssl_front == '1') {echo ' checked';}?>>
                    <label for="wpsw_ssl_front" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to enforce https for the front end for WordPress?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Enforce HTTPS on Admin Backend', 'wp-setup-wizard' ); ?></label></th>
        <td>
					<input type="checkbox" id="wpsw_ssl_admin" name="wpsw_ssl_admin" class="switch-input" <?php if($wpsw_ssl_admin == '1') {echo ' checked';}?>>
                    <label for="wpsw_ssl_admin" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to enforce https for the admin backend for WordPress?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Recaptcha v3 Site Key', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <div>
                    <input type="text" id="recaptchakey" placeholder="<?php esc_html_e( 'Recaptcha v3 key', 'wp-setup-wizard' ); ?>" name="recaptchakey" value="<?php echo esc_attr($recaptchakey);?>"/>
        </div>
        <span class="description">
                            <?php echo esc_html__("Set your Recaptcha v3 Site Key. You can get one, here: ", 'wp-setup-wizard') . ' <a href="https://www.google.com/recaptcha/admin/create" target="_blank">https://www.google.com/recaptcha/admin/create</a>'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Recaptcha v3 Site Secret', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <div>
                    <input type="password" id="recaptchasecret" autocomplete="off" placeholder="<?php esc_html_e( 'Recaptcha v3 secret', 'wp-setup-wizard' ); ?>" name="recaptchasecret" value="<?php echo esc_attr($recaptchasecret);?>"/>
        </div>
        <span class="description">
                            <?php echo esc_html__("Set your Recaptcha v3 Site Secret. You can get one, here: ", 'wp-setup-wizard') . ' <a href="https://www.google.com/recaptcha/admin/create" target="_blank">https://www.google.com/recaptcha/admin/create</a>'; ?>
                        </span>
        </td></tr>
		<tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Enable Captcha for the [wpsw-gdpr-form] Shortcode', 'wp-setup-wizard' ); ?></label></th>
        <td>
					<input type="checkbox" id="wpsw_captcha_shortcode" name="wpsw_captcha_shortcode" class="switch-input" <?php if($wpsw_captcha_shortcode == '1') {echo ' checked';}?>>
                    <label for="wpsw_captcha_shortcode" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to enable captcha for the [wpsw-gdpr-form] shortcode?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Enable Captcha for the [wpsw-contact-form] Shortcode', 'wp-setup-wizard' ); ?></label></th>
        <td>
					<input type="checkbox" id="wpsw_captcha_contact" name="wpsw_captcha_contact" class="switch-input" <?php if($wpsw_captcha_contact == '1') {echo ' checked';}?>>
                    <label for="wpsw_captcha_contact" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to enable captcha for the [wpsw-contact-form] shortcode?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Enable Captcha in the Login Form', 'wp-setup-wizard' ); ?></label></th>
        <td>
					<input type="checkbox" id="wpsw_captcha_login" name="wpsw_captcha_login" class="switch-input" <?php if($wpsw_captcha_login == '1') {echo ' checked';}?>>
                    <label for="wpsw_captcha_login" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to enable captcha for the login form?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr><th scope="row"><label for="show_time"><?php esc_html_e( 'Enable Captcha for the Comments Form', 'wp-setup-wizard' ); ?></label></th><td>
					<input type="checkbox" id="wpsw_captcha_comment" name="wpsw_captcha_comment" class="switch-input" <?php if($wpsw_captcha_comment == '1') {echo ' checked';}?>>
                    <label for="wpsw_captcha_comment" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to enable captcha for the comments form?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
            </table>

            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_security#vcc-Security') ) . '" target="_blank">';esc_html_e( 'Security Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
}
public function setup_step_legal() {
    $only_eu = get_option('wpsw_only_eu');
    $cookie_text = get_option('wpsw_cookie_text', esc_html__('Our site uses cookies.', 'wp-setup-wizard'));
    $accept_text = get_option('wpsw_accept_text', esc_html__('Accept', 'wp-setup-wizard'));
    $decline_text = get_option('wpsw_decline_text', esc_html__('Decline', 'wp-setup-wizard'));
    $cookie_url = get_option('wpsw_cookie_url');
    $decline_url = get_option('wpsw_decline_url');
    $cookie_pos = get_option('wpsw_cookie_pos', '0');
    $show_time = get_option('wpsw_show_time', 30);
    $learn_more = get_option('wpsw_learn_more', esc_html__('Learn more', 'wp-setup-wizard'));
        ?>
        <h1><?php esc_html_e( 'Legal Settings', 'wp-setup-wizard' ); ?></h1>

        <form method="post">

            <table class="form-table">
                <tr>
                    <th scope="row"><label for="enable_cookie"><?php esc_html_e( 'Enable Cookie Notice', 'wp-setup-wizard' ); ?></label></th>

                    <td class="updated">
                        <input type="checkbox" name="enable_cookie" id="enable_cookie" class="switch-input"<?php $comm_not = get_option('wpsw_enable_cookie');if($comm_not == '1') {echo ' checked';}?> >
                        <label for="enable_cookie" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                        <span class="description">
                            <?php esc_html_e( 'Do you want to enable cookie consent notice on your site?', 'wp-setup-wizard' ); ?>
                        </span>
                    </td>
                </tr>
                
      <tr class="cookie_hided">
      <th scope="row"><label for="only_eu"><?php esc_html_e( 'Show Cookie Notice Only To Visitors Located In The EU', 'wp-setup-wizard' ); ?></label></th>
    <td>
                    <input type="checkbox" id="only_eu" name="only_eu" class="switch-input"<?php if($only_eu == '1') {echo ' checked';}?> >
                    <label for="only_eu" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Do you want to show cookie notice only to visitors that are located inside the territory of the EU?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="cookie_text"><?php esc_html_e( 'Cookie Notice Text', 'wp-setup-wizard' ); ?></label></th><td>
                    <div>
                    <input type="text" id="cookie_text" placeholder="<?php esc_html_e( 'Cookie notice text', 'wp-setup-wizard' ); ?>" name="cookie_text" value="<?php echo esc_attr($cookie_text);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the cookie notice text that should appear in the cookie notice.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="accept_text"><?php esc_html_e( 'Accept Button Text', 'wp-setup-wizard' ); ?></label></th><td>
                    <div>
                    <input type="text" id="accept_text" placeholder="<?php esc_html_e( 'Accept button text', 'wp-setup-wizard' ); ?>" name="accept_text" value="<?php echo esc_attr($accept_text);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the accept button text that should appear in the cookie notice.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="decline_text"><?php esc_html_e( 'Decline Button Text', 'wp-setup-wizard' ); ?></label></th><td>
                    <div>
                    <input type="text" id="decline_text" placeholder="<?php esc_html_e( 'Decline button text', 'wp-setup-wizard' ); ?>" name="decline_text" value="<?php echo esc_attr($decline_text);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the decline button text that should appear in the cookie notice.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="learn_more"><?php esc_html_e( 'Learn More Button Text', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <div>
                    <input type="text" id="learn_more" placeholder="<?php esc_html_e( 'Learn more text', 'wp-setup-wizard' ); ?>" name="learn_more" value="<?php echo esc_attr($learn_more);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the learn more button text that should appear in the cookie notice.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="cookie_url"><?php esc_html_e( 'Learn More Button URL', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <div>
                    <input type="url" validator="url" pattern="https?://.*" id="cookie_url" placeholder="<?php esc_html_e( 'More info URL', 'wp-setup-wizard' ); ?>" name="cookie_url" value="<?php echo esc_attr($cookie_url);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the learn more button URL that should appear in the cookie notice.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="decline_url"><?php esc_html_e( 'Decline Button URL', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <div>
                    <input type="url" validator="url" pattern="https?://.*" id="decline_url" placeholder="<?php esc_html_e( 'Decline button URL', 'wp-setup-wizard' ); ?>" name="decline_url" value="<?php echo esc_attr($decline_url);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the decline button URL that should appear in the cookie notice.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="cookie_pos"><?php esc_html_e( 'Cookie Notice Position', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <div>
                    <select id="cookie_pos" name="cookie_pos"/>
                    <option value="0"<?php if($cookie_pos == '0'){echo ' selected';}?> ><?php esc_html_e( 'Bottom', 'wp-setup-wizard' ); ?></option>
                    <option value="1"<?php if($cookie_pos == '1'){echo ' selected';}?> ><?php esc_html_e( 'Top', 'wp-setup-wizard' ); ?></option>
                    </select>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the position of the cookie notice.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
        <tr class="cookie_hided">
        <th scope="row"><label for="show_time"><?php esc_html_e( 'Show Cookie Notice Again After (Days)', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <div>
                    <input type="number" min="1" step="1" id="show_time" placeholder="30" name="show_time" value="<?php echo esc_attr($show_time);?>"/>
        </div>
        <span class="description">
                            <?php esc_html_e( 'Set the amount of days after which the cookie consent will be shown again to the same visitor. Default is 30', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
            </table>

            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_legal#vcc-Cookie') ) . '" target="_blank">';esc_html_e( 'Legal Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }

public function setup_step_social() {
    $wpsw_enable_social = get_option('wpsw_enable_social');
	$wpsw_enable_pinit = get_option('wpsw_enable_pinit');
	$wpsw_enable_types = get_option('wpsw_enable_types', array());
	$wpsw_enable_position = get_option('wpsw_enable_position', 'Bottom');
	$wpsw_enable_align = get_option('wpsw_enable_align', 'None');
	$wpsw_enable_fb = get_option('wpsw_enable_fb');
	$wpsw_enable_tw = get_option('wpsw_enable_tw');
	$wpsw_enable_pt = get_option('wpsw_enable_pt');
	$wpsw_enable_li = get_option('wpsw_enable_li');
	$wpsw_enable_rd = get_option('wpsw_enable_rd');
        ?>
        <h1><?php esc_html_e( 'Social Settings', 'wp-setup-wizard' ); ?></h1>

        <form method="post"> 
        <table class="form-table">
      <tr><th scope="row"><label for="wpsw_enable_social"><?php esc_html_e( 'Enable Social Share Buttons', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_enable_social" class="switch-input wpsw_enable_social" name="wpsw_enable_social" <?php if($wpsw_enable_social == '1') {echo ' checked';}?>>
                    <label for="wpsw_enable_social" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php esc_html_e( 'Check this checkbox to enable social sharing buttons on your site.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
      <tr class="social_hided"><th scope="row"><label for="wpsw_enable_meta"><?php esc_html_e( 'Show on Post Types', 'wp-setup-wizard' ); ?></label></th>
      <td>
<?php
		$args = array(
		   'public'   => true,
		   '_builtin' => true
		);
		  
		$output = 'names';
		$operator = 'and';
		if(!is_array($wpsw_enable_types))
		{
			$wpsw_enable_types = array();
		}
		$post_types = get_post_types( $args, $output, $operator );
        echo '<select multiple name="wpsw_enable_types[]" id="wpsw_enable_types">';
		foreach($post_types as $pt)
		{
			echo '<option value="' . $pt . '"';
			if(in_array($pt, $wpsw_enable_types))
			{
				echo ' selected="selected"';
			}
			echo '>' . $pt . '</option>';
		}
        echo '</select>';
?> 
        <span class="description">
                            <?php esc_html_e( 'Select the post types for which to activate the sharing buttons.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr class="social_hided"><th scope="row"><label for="wpsw_enable_meta"><?php esc_html_e( 'Sharing Buttons Position', 'wp-setup-wizard' ); ?></label></th>
        <td>
<?php
		echo '<select name="wpsw_enable_position" id="wpsw_enable_position">';
		$position_types = array('Top', 'Bottom');
		foreach($position_types as $pt)
		{
			echo '<option value="' . $pt . '"';
			if($pt == $wpsw_enable_position)
			{
				echo ' selected="selected"';
			}
			echo '>' . $pt . '</option>';
		}
        echo '</select>';
?> 
        <span class="description">
                            <?php esc_html_e( 'Select the position of the sharing buttons.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr class="social_hided"><th scope="row"><label for="wpsw_enable_meta"><?php esc_html_e( 'Sharing Buttons Alignment', 'wp-setup-wizard' ); ?></label></th>
        <td>
<?php
		echo '<select name="wpsw_enable_align" id="wpsw_enable_align">';
		$position_types = array('None', 'Left', 'Center', 'Right');
		foreach($position_types as $pt)
		{
			echo '<option value="' . $pt . '"';
			if($pt == $wpsw_enable_align)
			{
				echo ' selected="selected"';
			}
			echo '>' . $pt . '</option>';
		}
        echo '</select>';
?> 
        <span class="description">
                            <?php esc_html_e( 'Select the alignment of the sharing buttons.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
		<tr class="social_hided"><th scope="row"><label for="wpsw_enable_fb"><?php esc_html_e( 'Sharing Buttons To Enable', 'wp-setup-wizard' ); ?></label></th>
        <td>
			<table><tr><td>Facebook</td><td><input type="checkbox" id="wpsw_enable_fb" class="switch-input wpsw_enable_fb" name="wpsw_enable_fb" <?php if($wpsw_enable_fb == '1') {echo ' checked';}?>>
            <label for="wpsw_enable_fb" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label></td></tr>
			<tr><td>Twitter</td><td><input type="checkbox" id="wpsw_enable_tw" class="switch-input wpsw_enable_tw" name="wpsw_enable_tw" <?php if($wpsw_enable_tw == '1') {echo ' checked';}?>>
            <label for="wpsw_enable_tw" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label></td></tr>
			<tr><td>Pinterest</td><td><input type="checkbox" id="wpsw_enable_pt" class="switch-input wpsw_enable_pt" name="wpsw_enable_pt" <?php if($wpsw_enable_pt == '1') {echo ' checked';}?>>
            <label for="wpsw_enable_pt" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label></td></tr>
			<tr><td>LinkedIn</td><td><input type="checkbox" id="wpsw_enable_li" class="switch-input wpsw_enable_li" name="wpsw_enable_li" <?php if($wpsw_enable_li == '1') {echo ' checked';}?>>
            <label for="wpsw_enable_li" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label></td></tr>
			<tr><td>Reddit</td><td><input type="checkbox" id="wpsw_enable_rd" class="switch-input wpsw_enable_rd" name="wpsw_enable_rd" <?php if($wpsw_enable_rd == '1') {echo ' checked';}?>>
            <label for="wpsw_enable_rd" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label></td></tr>
                        </table>
        <span class="description">
                            <?php esc_html_e( 'Select the sharing buttons to enable.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
      <tr><th scope="row"><label for="wpsw_enable_pinit"><?php esc_html_e( 'Enable "Pin It" Feature For Images', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_enable_pinit" class="switch-input wpsw_enable_pinit" name="wpsw_enable_pinit" <?php if($wpsw_enable_pinit == '1') {echo ' checked';}?>>
                    <label for="wpsw_enable_pinit" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php esc_html_e( 'Check this checkbox to enable the \'Pin It\' feature for images from your site.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
            </table>

            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_seo#vcc-SEO') ) . '" target="_blank">';esc_html_e( 'SEO Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }
    
public function setup_step_monetize() {
    $wpsw_google_adsense = get_option('wpsw_google_adsense');
    $wpsw_amazon = get_option('wpsw_amazon');
    $wpsw_amazon = get_option('wpsw_amazon');
	$wpsw_ebay = get_option('wpsw_ebay');
	$wpsw_cb = get_option('wpsw_cb');
	$wpsw_cj = get_option('wpsw_cj');
	$wpsw_gb = get_option('wpsw_gb');
	$wpsw_al = get_option('wpsw_al');
	$wpsw_en = get_option('wpsw_en');
	$wpsw_wm = get_option('wpsw_wm');
	$wpsw_et = get_option('wpsw_et');
        ?>
        <h1><?php esc_html_e( 'Monetize Settings', 'wp-setup-wizard' ); ?></h1>

        <form method="post"> 
        <table class="form-table">
      <tr><th scope="row"><label for="wpsw_google_adsense"><?php esc_html_e( 'AdSense Publisher ID', 'wp-setup-wizard' ); ?></label></th>
        <td><input type="text" placeholder="pub-xxxxxxxxxxxxxxxx" name="wpsw_google_adsense" value="<?php echo esc_attr($wpsw_google_adsense);?>" id="wpsw_google_adsense" class="wpsw-date-field">
        <span class="description">
                            <?php echo esc_html__("Enter your Google AdSense Publisher ID, for example: ", 'wp-setup-wizard') . '<br/>pub-xxxxxxxxxxxxxxxx'; ?>
                        </span>
        </td></tr><tr><th scope="row"><label for="wpsw_amazon"><?php esc_html_e( 'Enable Amazon Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_amazon" class="switch-input wpsw_amazon" name="wpsw_amazon" <?php if($wpsw_amazon == '1') {echo ' checked';}?>>
                    <label for="wpsw_amazon" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-Amazon') ) . '" target="_blank">' . esc_html__("Amazon Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_ebay"><?php esc_html_e( 'Enable eBay Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_ebay" class="switch-input wpsw_ebay" name="wpsw_ebay" <?php if($wpsw_ebay == '1') {echo ' checked';}?>>
                    <label for="wpsw_ebay" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-Ebay') ) . '" target="_blank">' . esc_html__("eBay Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_cb"><?php esc_html_e( 'Enable ClickBank Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_cb" class="switch-input wpsw_cb" name="wpsw_cb" <?php if($wpsw_cb == '1') {echo ' checked';}?>>
                    <label for="wpsw_cb" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-CB') ) . '" target="_blank">' . esc_html__("ClickBank Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_cj"><?php esc_html_e( 'Enable Commission Junction Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_cj" class="switch-input wpsw_cj" name="wpsw_cj" <?php if($wpsw_cj == '1') {echo ' checked';}?>>
                    <label for="wpsw_cj" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-CJ') ) . '" target="_blank">' . esc_html__("Commission Junction Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_gb"><?php esc_html_e( 'Enable GearBest Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_gb" class="switch-input wpsw_gb" name="wpsw_gb" <?php if($wpsw_gb == '1') {echo ' checked';}?>>
                    <label for="wpsw_gb" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-GB') ) . '" target="_blank">' . esc_html__("GearBest Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_al"><?php esc_html_e( 'Enable AliExpress Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_al" class="switch-input wpsw_al" name="wpsw_al" <?php if($wpsw_al == '1') {echo ' checked';}?>>
                    <label for="wpsw_al" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-AL') ) . '" target="_blank">' . esc_html__("AliExpress Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_en"><?php esc_html_e( 'Enable Envato Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_en" class="switch-input wpsw_en" name="wpsw_en" <?php if($wpsw_en == '1') {echo ' checked';}?>>
                    <label for="wpsw_en" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-EN') ) . '" target="_blank">' . esc_html__("Envato Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_wm"><?php esc_html_e( 'Enable Walmart Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_wm" class="switch-input wpsw_wm" name="wpsw_wm" <?php if($wpsw_wm == '1') {echo ' checked';}?>>
                    <label for="wpsw_wm" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-WM') ) . '" target="_blank">' . esc_html__("Walmart Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        <tr><th scope="row"><label for="wpsw_et"><?php esc_html_e( 'Enable Etsy Affiliate Ads', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_et" class="switch-input wpsw_et" name="wpsw_et" <?php if($wpsw_et == '1') {echo ' checked';}?>>
                    <label for="wpsw_et" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        <span class="description">
                            <?php echo esc_html__("Check this checkbox to enable affiliate ads to be shown inside the content of your posts. For a complete setup, visit ", 'wp-setup-wizard') . '<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-ET') ) . '" target="_blank">' . esc_html__("Etsy Settings", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
        </td></tr>
        </table>
            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_monetize#vcc-Monetize') ) . '" target="_blank">';esc_html_e( 'Monetize Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }
    
public function setup_step_speed() {
    $wpsw_combine_js = get_option('wpsw_combine_js');
	$wpsw_combine_css = get_option('wpsw_combine_css');
	$wpsw_remove_query = get_option('wpsw_remove_query');
	$wpsw_gzip = get_option('wpsw_gzip');
	$wpsw_leverage = get_option('wpsw_leverage');
        ?>
        <h1><?php esc_html_e( 'Page Speed Settings', 'wp-setup-wizard' ); ?></h1>

        <form method="post"> 
        <table class="form-table">
        <tr><th scope="row"><label for="wpsw_combine_js"><?php esc_html_e( 'Minify and Combine HTML & JavaScript', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <input type="checkbox" class="switch-input" id="wpsw_combine_js" name="wpsw_combine_js" <?php if($wpsw_combine_js == '1') {echo ' checked';}?>>
                    <label for="wpsw_combine_js" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php echo esc_html__("Do you want to enable the minification and JavaScript combining feature?", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
                        </td></tr>
        <tr><th scope="row"><label for="wpsw_combine_css"><?php esc_html_e( 'Minify and Combine CSS', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <input type="checkbox" class="switch-input" id="wpsw_combine_css" name="wpsw_combine_css" <?php if($wpsw_combine_css == '1') {echo ' checked';}?>>
                    <label for="wpsw_combine_css" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php echo esc_html__("Do you want to enable the minification and CSS combining feature?", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
                        </td></tr>
        <tr><th scope="row"><label for="wpsw_remove_query"><?php esc_html_e( 'Remove Query Strings', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <input type="checkbox" class="switch-input" id="wpsw_remove_query" name="wpsw_remove_query" <?php if($wpsw_remove_query == '1') {echo ' checked';}?>>
                    <label for="wpsw_remove_query" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php echo esc_html__("Do you want to remove query strings from static content?", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
                        </td></tr>
        <tr><th scope="row"><label for="wpsw_gzip"><?php esc_html_e( 'Enable GZIP Compression', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <?php
                    if(function_exists('ob_gzhandler'))
                    {
                    ?>
                    <b><?php esc_html_e( 'GZIP Compression is not available on your server!', 'wp-setup-wizard' ); ?></b>
                    <input type="hidden" id="wpsw_gzip" name="wpsw_gzip" value="0">
                    <?php
                    }
                    else
                    {
                    ?>
                    <input type="checkbox" class="switch-input" id="wpsw_gzip" name="wpsw_gzip" <?php if($wpsw_gzip == '1') {echo ' checked';}?>>
                    <label for="wpsw_gzip" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
                    <?php
                    }
                    ?>
        </div>
        <span class="description">
                            <?php echo esc_html__("Do you want to enable GZIP compression (compress text, HTML, JavaScript, CSS, XML)?", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
                        </td></tr>
        <tr><th scope="row"><label for="wpsw_leverage"><?php esc_html_e( 'Leverage Browser Caching', 'wp-setup-wizard' ); ?></label></th>
        <td>
                    <input type="checkbox" class="switch-input" id="wpsw_leverage" name="wpsw_leverage" <?php if($wpsw_leverage == '1') {echo ' checked';}?>>
                    <label for="wpsw_leverage" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        <span class="description">
                            <?php echo esc_html__("Do you want to Leverage Browser Caching (set expire caching)?", 'wp-setup-wizard') . '</a>.'; ?>
                        </span>
                        </td></tr>
        </table>
            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_speed#vcc-Optim') ) . '" target="_blank">';esc_html_e( 'Speed Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }

public function setup_step_seo() {
    $wpsw_enable_meta = get_option('wpsw_enable_meta');
	$wpsw_noindex = get_option('blog_public', 1);
	$wpsw_redirect404 = get_option('wpsw_redirect404');
        ?>
        <h1><?php esc_html_e( 'SEO Settings', 'wp-setup-wizard' ); ?></h1>

        <form method="post"> 
        <table class="form-table">
      <tr><th scope="row"><label for="wpsw_enable_meta"><?php esc_html_e( 'Enable SEO Meta Tags', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_enable_meta" class="switch-input wpsw_enable_meta" name="wpsw_enable_meta" <?php if($wpsw_enable_meta == '1') {echo ' checked';}?>>
                    <label for="wpsw_enable_meta" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        
                        <span class="description">
                            <?php esc_html_e( 'Check this checkbox to enable SEO meta tag creation for your site. It will create Facebook, Twitter and generic SEO meta tags.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
      <tr><th scope="row"><label for="wpsw_noindex"><?php esc_html_e( 'Discourage Search Engines From Indexing Your Site', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_noindex" class="switch-input" name="wpsw_noindex" <?php if($wpsw_noindex == '0') {echo ' checked';}?>>
                    <label for="wpsw_noindex" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        
                        <span class="description">
                            <?php esc_html_e( 'Check this checkbox to tell search engines to not index your site.', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
      <tr><th scope="row"><label for="wpsw_redirect404"><?php esc_html_e( 'Redirect 404 Errors to Home Page', 'wp-setup-wizard' ); ?></label></th>
      <td>
                    <input type="checkbox" id="wpsw_redirect404" class="switch-input" name="wpsw_redirect404" <?php if($wpsw_redirect404 == '1') {echo ' checked';}?>>
                    <label for="wpsw_redirect404" class="switch-label">
                            <span class="toggle--on"><?php esc_html_e( 'On', 'wp-setup-wizard' ); ?></span>
                            <span class="toggle--off"><?php esc_html_e( 'Off', 'wp-setup-wizard' ); ?></span>
                        </label>
        </div>
        
                        <span class="description">
                            <?php esc_html_e( 'Do you want to redirect 404 errors to home page?', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
            </table>

            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_social#vcc-Social') ) . '" target="_blank">';esc_html_e( 'Social Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }

    public function setup_step_basic_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizcont');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_legal_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizleg');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_gdpr_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizgdpr');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_security_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizsec');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_seo_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizseo');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_social_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizsoc');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_monetize_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizmon');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_speed_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizspe');
        wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        exit;
    }
    public function setup_step_theme_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wiztheme');
        if(headers_sent())
        {
            echo '<meta http-equiv="refresh" content="0; url=' . esc_url_raw( $this->get_next_step_link() ) . '">';
        }
        else
        {
            wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        }
        exit;
    }
    public function setup_step_plugin_save() {
        check_admin_referer( 'wpsw_show_setup_wiz' );
        wpsw_update_site_settings('wizplug');
        if(headers_sent())
        {
            echo '<meta http-equiv="refresh" content="0; url=' . esc_url_raw( $this->get_next_step_link() ) . '">';
        }
        else
        {
            wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
        }
        exit;
    }
    
    public function setup_step_theme() {
        ?>
        <h1><?php esc_html_e( 'Theme Setup', 'wp-setup-wizard' ); ?></h1>
        <form method="post" class="form-table">

            <table class="form-table">
                <tr>
                <th scope="row"><label for="show_time"><?php esc_html_e( 'List of Theme URLs to Install', 'wp-setup-wizard' ); ?></label></th><td>
                    <textarea rows="6" class="gs_popuptype_holderx" placeholder="<?php esc_html_e( 'Enter a list of theme urls to install', 'wp-setup-wizard' ); ?>" id="wpsw-manual-themes" name="wpsw_manual_themes"></textarea>
        
        </div>
        <span class="description">
                            <?php esc_html_e( 'Add a comma separated list of WordPress theme URLs to install automatically. The URL can be a repository URL: https://wordpress.org/themes/generatepress/ or the direct URL to the zip file: https://coderevolution.ro/path/to/the/theme-file.zip', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
            </table>

            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_themes') ) . '" target="_blank">';esc_html_e( 'Theme Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }
    public function setup_step_plugin() {
        ?>
        <h1><?php esc_html_e( 'Plugin Setup', 'wp-setup-wizard' ); ?></h1>
        <form method="post" class="form-table">

            <table class="form-table">
                <tr>
                <th scope="row"><label for="show_time"><?php esc_html_e( 'List of Plugin URLs to Install', 'wp-setup-wizard' ); ?></label></th><td>
                    <textarea rows="6" class="gs_popuptype_holderx" placeholder="<?php esc_html_e( 'Enter a list of plugin urls to install', 'wp-setup-wizard' ); ?>" id="wpsw-manual-plugins" name="wpsw_manual_plugins"></textarea>
        
        </div>
        <span class="description">
                            <?php esc_html_e( 'Add a comma separated list of WordPress plugin URLs to install automatically. The URL can be a repository URL: https://wordpress.org/plugins/wp-pocket-urls/ or the direct URL to the zip file: https://coderevolution.ro/path/to/the/plugin-file.zip', 'wp-setup-wizard' ); ?>
                        </span>
        </td></tr>
            </table>

            <?php $this->next_step_buttons(); ?>
        </form>
        <span><?php esc_html_e( 'For more settings, check the plugin\'s ', 'wp-setup-wizard' ); echo '"<a href="' . esc_url_raw( admin_url('admin.php?page=wpsw_plugins') ) . '" target="_blank">';esc_html_e( 'Plugin Settings', 'wp-setup-wizard' ); echo '</a>".'; ?></span>
        <br/><br/>
        <?php
    }

    public function setup_step_ready() {
        ?>

        <div class="final-step">
            <h1><?php esc_html_e( 'Your Site is Ready!', 'wp-setup-wizard' ); ?></h1>

            <div class="wpsw-setup-next-steps">
                <div class="wpsw-setup-next-steps-first">
                    <h2><?php esc_html_e( 'Next Steps', 'wp-setup-wizard' ); ?> &rarr;</h2>
                        <a class="button button-primary button-large"
                            href="<?php echo esc_url_raw( admin_url('admin.php?page=wpsw_welcome_settings&wpsw_done_config=1') ); ?>">
                            <?php esc_html_e( 'Go to WP Setup Wizard Dashboard!', 'wp-setup-wizard' );
                                   ?>
                        </a>
                </div>
            </div>
        </div>
        <?php
    }
}