<?php

if ( ! class_exists( 'DB_Reset_Admin' ) ) :

  class DB_Reset_Admin {

    private $code;
    private $notice_error;
    private $notice_success;
    private $request;
    private $resetter;
    private $user;
    private $version;
    private $wp_tables;

    public function __construct( $version ) {
      $this->resetter = new DB_Resetter();
      $this->version = $version;

      $this->set_request( $_REQUEST );
      $this->set_view_variables();
    }

    private function set_request( array $request ) {
      $this->request = $request;
    }

    private function set_view_variables() {
      $this->set_code();
      $this->set_user();
      $this->set_wp_tables();
    }

    private function set_code() {
      $this->code = $this->generate_code();
    }

    private function set_user() {
      $this->user = $this->resetter->get_user();
    }

    private function set_wp_tables() {
      $this->wp_tables = $this->resetter->get_wp_tables();
    }

    private function generate_code( $length = 5 ) {
      return substr( md5( time() ), 1, $length );
    }

    public function run() {
      add_action( 'admin_init', array( $this, 'reset' ) );
    }

    public function reset() {

      if ( $this->form_is_safe_to_submit() ) {
        try {
          $this->resetter->set_reactivate( $this->request[ 'db-reset-reactivate-theme-data' ] );
          $this->resetter->reset( $this->request[ 'db-reset-tables' ] );
          $this->handle_after_reset();
        } catch ( Exception $e ) {
          $this->notice_error = $e->getMessage();
        }
      }
    }

    private function form_is_safe_to_submit() {
      return isset( $this->request['db-reset-code-confirm'] ) &&
             $this->assert_request_variables_not_empty();
    }

    private function handle_after_reset() {
      if ( empty( $this->request[ 'db-reset-reactivate-theme-data' ] ) ) {
        wp_redirect( admin_url() );
        exit;
      }

      $this->notice_success = esc_html__( 'The selected tables were reset', 'wp-setup-wizard' );
    }

    private function assert_request_variables_not_empty() {
      $this->set_empty_request_key( 'db-reset-tables', array() );
      $this->set_empty_request_key( 'db-reset-reactivate-theme-data', false );

      return true;
    }

    private function set_empty_request_key( $key, $default ) {
      if ( ! array_key_exists( $key, $this->request ) ) {
        $this->request[ $key ] = $default;
      }
    }

    private function assert_correct_code() {
      if ( $this->request['db-reset-code'] !==
           $this->request['db-reset-code-confirm'] ) {
        $this->notice_error = esc_html__( 'You entered the wrong security code', 'wp-setup-wizard' );
        return false;
      }

      return true;
    }

    public function render() {
      require_once( DB_RESET_PATH . '/views/index.php' );
    }

  }

endif;
